const svg = d3.select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

// Load data from CSV
d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/74352799233a05a3ad0496cbc361e3c1/raw/ecdca534f39a1a2051ee63bb7c979fcb59eb8216/amazon_prime_titles.csv',
).then(function (data) {
  // Filter data to include only movies
  const movies = data.filter(
    (item) => item.type === 'Movie',
  );

  // Group movies by genre
  const genres = {};
  movies.forEach(function (movie) {
    const genre = movie.listed_in.split(',')[0].trim();
    if (!genres[genre]) {
      genres[genre] = [];
    }
    if (genres[genre].length < 3) {
      genres[genre].push(movie.title);
    }
  });

  // Structure the data for the graph
  const nodes = [
    { id: 'Movies', type: 'Category' },
    { id: 'Comedy', type: 'Genre' },
    { id: 'Documentary', type: 'Genre' },
    { id: 'Drama', type: 'Genre' },
  ];

  const links = [
    { source: 'Movies', target: 'Comedy' },
    { source: 'Movies', target: 'Documentary' },
    { source: 'Movies', target: 'Drama' },
  ];

  genres['Comedy'].forEach((title) => {
    nodes.push({ id: title, type: 'Title' });
    links.push({ source: 'Comedy', target: title });
  });

  genres['Documentary'].forEach((title) => {
    nodes.push({ id: title, type: 'Title' });
    links.push({ source: 'Documentary', target: title });
  });

  genres['Drama'].forEach((title) => {
    nodes.push({ id: title, type: 'Title' });
    links.push({ source: 'Drama', target: title });
  });

  // Create the color scale for node types
  const colorScale = d3
    .scaleOrdinal()
    .domain(['Category', 'Genre', 'Title'])
    .range(['#66c2a5', '#fc8d62', '#8da0eb']);

  // Create the force simulation
  const simulation = d3
    .forceSimulation(nodes)
    .force(
      'link',
      d3
        .forceLink(links)
        .id((d) => d.id)
        .distance(120),
    )
    .force('charge', d3.forceManyBody().strength(-500))
    .force('center', d3.forceCenter(width / 2, height / 2));

  // Append links to SVG
  const link = svg
    .append('g')
    .selectAll('line')
    .data(links)
    .enter()
    .append('line')
    .attr('class', 'link')
    .style('stroke-width', 2)
    .attr('marker-end', 'url(#arrow)');

  // Create nodes
  const node = svg
    .selectAll('.node')
    .data(nodes)
    .enter()
    .append('circle')
    .attr('class', 'node')
    .attr('r', (d) => (d.type === 'Category' ? 30 : 25)) // Adjust circle size for titles
    .style('fill', (d) => colorScale(d.type));

  // Add node labels
  const nodeLabels = svg
    .selectAll('.node-label')
    .data(nodes)
    .enter()
    .append('text')
    .attr('class', 'node-label')
    .text((d) => d.id);

  // Add title
  svg
    .append('text')
    .attr('x', width / 4)
    .attr('y', 50)
    .attr('text-anchor', 'middle')
    .attr('font-size', '24px')
    .text('Network Graph Visualization');

  // Add simulation tick function
  simulation.on('tick', () => {
    link
      .attr('x1', (d) => d.source.x)
      .attr('y1', (d) => d.source.y)
      .attr('x2', (d) => d.target.x)
      .attr('y2', (d) => d.target.y);

    node.attr('cx', (d) => d.x).attr('cy', (d) => d.y);

    nodeLabels.attr('x', (d) => d.x).attr('y', (d) => d.y);
  });
});
